package com.ruoyi.bst.device.service;

import java.util.List;

import com.ruoyi.bst.device.domain.Device;
import com.ruoyi.bst.device.domain.DeviceQuery;
import com.ruoyi.bst.device.domain.DeviceVO;
import com.ruoyi.bst.device.domain.vo.DeviceMacSnVO;

/**
 * 设备Service接口
 *
 * @author ruoyi
 * @date 2025-03-20
 */
public interface DeviceService
{
    /**
     * 查询设备
     *
     * @param id 设备主键
     * @return 设备
     */
    public DeviceVO selectDeviceById(Long id, boolean scope);

    default DeviceVO selectDeviceById(Long id) {
        return this.selectDeviceById(id, false);
    }

    /**
     * 查询设备列表
     *
     * @param device 设备
     * @return 设备集合
     */
    public List<DeviceVO> selectDeviceList(DeviceQuery device);

    /**
     * 新增设备
     *
     * @param device 设备
     * @return 结果
     */
    public int insertDevice(Device device);

    /**
     * 修改设备
     *
     * @param device 设备
     * @return 结果
     */
    public int updateDevice(Device device);

    /**
     * 批量删除设备
     *
     * @param ids 需要删除的设备主键集合
     * @return 结果
     */
    public int deleteDeviceByIds(Long[] ids);

    /**
     * 删除设备信息
     *
     * @param id 设备主键
     * @return 结果
     */
    public int deleteDeviceById(Long id);

    /**
     * 逻辑删除设备
     *
     * @param ids 需要删除的设备主键集合
     * @return 结果
     */
    public int logicDel(List<Long> ids);


    /**
     * 查询设备列表
     * @param ids
     * @param scope
     * @return
     */
    public List<DeviceVO> selectDeviceByIds(List<Long> ids, boolean scope);

    default List<DeviceVO> selectDeviceByIds(List<Long> ids) {
        return this.selectDeviceByIds(ids, false);
    }

    /**
     * 入仓
     */
    public int in(List<DeviceVO> deviceList);

    /**
     * 出仓
     */
    public int out(List<DeviceVO> deviceList);

    /**
     * 禁用
     */
    public int disable(List<DeviceVO> deviceList);

    /**
     * 启用
     */
    public int enable(List<DeviceVO> deviceList);

    /**
     * 根据sn查询设备
     * @param sn 设备sn
     * @param scope 是否数据隔离
     * @return 设备
     */
    public DeviceVO selectDeviceBySn(String sn, boolean scope);

    default DeviceVO selectDeviceBySn(String sn) {
        return this.selectDeviceBySn(sn, false);
    }

    /**
     * 根据mac查询简单的设备信息，仅包含了定位日志所需的数据
     * @param mac 设备mac
     * @return
     */
    public DeviceVO selectSimpleByMacForLocationLog(String mac);

    /**
     * 查询一个
     */
    public DeviceVO selectOne(DeviceQuery query);

    /**
     * 更新设备当前订单ID
     * @param id 设备ID
     * @param deviceOrderId 设备订单ID
     * @return 结果
     */
    public int updateCurrentDeviceOrderId(Long id, Long deviceOrderId);

    /**
     * 清除设备当前订单ID
     * @param id 设备ID
     * @param orderDeviceId 订单设备ID
     * @return 结果
     */
    public int clearCurrentOrderDevice(Long id, Long orderDeviceId);

    /**
     * 根据mac更新在线状态
     */
    int updateOnlineStatusByMac(String mac, String onlineStatus);

    /**
     * 划拨运营区
     */
    public int transfer(List<DeviceVO> deviceList, Long areaId);

    /**
     * 获取可用车辆
     */
    public DeviceVO selectAvaliableDevice(Long id, String sn);

    /**
     * 根据mac查询设备
     * @param mac
     * @return
     */
    public DeviceVO selectByMac(String mac);

    /**
     * 解绑所属用户
     */
    public int unbindMch(List<DeviceVO> deviceList);

    /**
     * 解绑运营区
     */
    public int unbindArea(List<DeviceVO> deviceList);

    /**
     * 更新设备最后一次使用的用户ID
     * @param id 设备ID
     * @param lastUserId 最后一次使用的用户ID
     * @return 结果
     */
    public int updateLastUserId(Long id, Long lastUserId);

    /**
     * 根据mac查询订单ID
     * @param mac
     * @return
     */
    public Long selectOrderIdByMac(String mac);

    /**
     * 根据mac查询SN
     * @param macList
     * @return
     */
    public List<DeviceMacSnVO> listSnByMac(List<String> macList);

    /**
     * 条件更新
     * @param data
     * @param query
     * @return
     */
    public int updateByQuery(Device data, DeviceQuery query);


}
